@@ -1,3 +1,4 @@
-default_app_config = 'webpack_loader.apps.WebpackLoaderConfig'
+__author__ = 'Owais Lone'
+__version__ = '0.3.3'
 
-from .utils import get_bundle
+default_app_config = 'webpack_loader.apps.WebpackLoaderConfig'
